function profiles = profiles_from_AFS3D(AFS,V,bndpts,hx)
% computes the feasible profiles from a 3D-AFS for a four component system
% 
% input:
% AFS ...... area of feasible solutions computed by facpack
% V ........ matrix of the right singular vectors
% bndpts ... number of boundary points for each AFS-subset
% hx ....... stepsize for the ray-discretization
% 
% example:
% profiles = profiles_from_AFS3D(AFS, V, 200, 0.1)

col = [0     0.4470     0.7410;
    0.8500    0.3250    0.0980;
    0.9290    0.6940    0.1250;
    0.4940    0.1840    0.5560;
    0.4660    0.6740    0.1880;
    0.3010    0.7450    0.9330];

profiles = [];

for seg=1:AFS.nseg
    if AFS.SegStruc(seg,1) == 1
        nb = floor(size(AFS.seg{seg}.pts,1)/bndpts);

        OUT = AFS.seg{seg}.OUT;
        INN = AFS.seg{seg}.INN;

        if size(OUT, 1) == 0
            return
        end

        [mi,id(1)] = max(OUT(:,1));
        [mi,id(2)] = min(OUT(:,1));
        [mi,id(3)] = max(OUT(:,2));
        [mi,id(4)] = min(OUT(:,2));
        [mi,id(5)] = max(OUT(:,3));
        [mi,id(6)] = min(OUT(:,3));

        for i=1:nb:size(OUT,1)
            id(end+1) = i;
        end

        id = unique(id);
        T = OUT(id,:);

        ID = id;

        id= [];
        [mi,id(1)] = max(INN(:,1));
        [mi,id(2)] = min(INN(:,1));
        [mi,id(3)] = max(INN(:,2));
        [mi,id(4)] = min(INN(:,2));
        [mi,id(5)] = max(INN(:,3));
        [mi,id(6)] = min(INN(:,3));
        for i=1:nb:size(INN,1)-floor(nb/2)
            id(end+1) = i+floor(nb/2);
        end
        
        id = unique(id);
        T = [T; INN(id,:)];
        
        ID = unique([ID, id]);
        
        for i=ID
            nx = round(norm(OUT(i,:)-INN(i,:),2)/hx);
            al = linspace(0,1,nx+2);
            for j=2:nx+1
                T = [T; al(j)*OUT(i,:)+(1-al(j))*INN(i,:)];
            end
        end
        
        profiles{seg} = [ones(size(T,1),1) T]*V';

    elseif AFS.SegStruc(seg,1) == 2
        
        nb = floor(size(AFS.seg{seg}.pts,1)/bndpts);
        
        T = AFS.seg{AFS.SegStruc(seg,2)}.plane;
        T = [T; AFS.seg{seg}.OUT(1:nb:end,:)];
        
        profiles{seg} = [ones(size(T,1),1) T]*V';
        
    elseif AFS.SegStruc(seg,1) == 3
        pts = AFS.lines{AFS.SegStruc(seg,2)}.pts(1:2,:);
        T = pts;
        
        nx = round(norm(pts(2,:)-pts(1,:),2)/hx);
        al = linspace(0,1,nx+2);
        for j=2:nx+1
            T = [T; al(j)*pts(1,:)+(1-al(j))*pts(2,:)];
        end
        
        profiles{seg} = [ones(size(T,1),1) T]*V';
        
    elseif AFS.SegStruc(seg,1) == 4
        T = AFS.seg{AFS.SegStruc(seg,2)}.pts(1,:);
        
        profiles{seg} = [ones(size(T,1),1) T]*V';
    end
    
    figure(seg)
    plot(1:size(V,1), profiles{seg}, 'color', col(seg,:))
    axis tight
    yl = get(gca, 'ylim');
    set(gca, 'ylim',[min(0, yl(1)), yl(2)]);
end
